@@ -24,28 +24,31 @@ def analyzer_pre_processing(abstracts_log_name, status_logger_name):
 	'''Carries out the pre-processing tasks, such as folder creation'''
 	analyzer_pre_processing_status_key="Carrying out pre-processing functions for analyzer"
 	status_logger(status_logger_name, analyzer_pre_processing_status_key)
-	
+
+	try:
+		'''If the Analyzer script is run independently, not as part of the pipeline as a whole, there would be no filename_CLEAND.txt.
+		This ensures that that file can be processed independently.'''
+		abstracts_txt_file_name = (abstracts_log_name.split(".txt")[0])+"_"+'CLEANED.txt'
+		open(abstracts_txt_file_name, 'r')
+	except FileNotFoundError:
+		abstracts_txt_file_name = (abstracts_log_name.split(".txt")[0])+'.txt'
+
 	'''This code strips the abstracts_log_name of its extension and adds a .csv to it'''
-	abstracts_csv_file_name=(os.path.splitext(abstracts_log_name)[0])+"_"+"FREQUENCY_CSV_DATA"+".csv"
-	abstracts_txt_file_name = abstracts_log_name+"_"+"CLEANED"+".txt"
-	
+	abstracts_csv_file_name = (abstracts_log_name.split(".txt")[0]) + "_" + "FREQUENCY_CSV_DATA" + ".csv"
+
 	analyzer_pre_processing_status_key = "Carried out pre-processing functions for analyzer"
 	status_logger(status_logger_name, analyzer_pre_processing_status_key)
+
 	return abstracts_txt_file_name, abstracts_csv_file_name
 
 def list_cleaner(list_to_be_cleaned, status_logger_name):
 	list_cleaner_start_status_key = "Cleaning the list of words generated"
 	status_logger(status_logger_name, list_cleaner_start_status_key)
-	
-	'''This function cleans the list containing the words found in the abstract. It eliminates words found in
-	another pre-defined list of words.'''
-	words_to_be_eliminated = ["the", "of", "and", "in", "to", "a", "is", "for", "from", "with", "that",	"by", "are", "on", "was", "as", "were", "url:", "abstract:",
-	"abstract",  "author:", "title:", "at", "be", "an", "during", "have", "this", "which", "study", "been", "species", "not", "has", "between",
-	"using", "its", "also", "these", "this", "used", "over", "can", "within", "into", "all","due", "use", "about", "a", 'it', 'their', "where", "we", "most", "may", "through",
-	"though", "like", "or", "further", "e.g.", "along", "any", "those", "had", "toward", "due", "both", "some", "use", "even", "more", "but", "while", "pass", 
-	"well", "will", "when", "only", "after", "author", "title", "there", "our", "did", "much", "as", "if", "become", "still", "various", "very", "out",
-	"they", "via", "available", "such", "than", "different", "many", "areas", "no", "one", "two", "small", "first", "other", "such", "-", "could", "studies", "high",
-	"provide", "among", "highly", "no", "case", "across", "given", "need", "would", "under", "found", "low", "values", "xe2\\x80\\x89", "xa", "xc", "xb", "\xc2\xa0C\xc2\xa0ha\xe2\x88\x921", "suggest", "up", "'The", "area"] 
+
+	'''This function cleans the list containing the words found in the abstract. It eliminates words found in another pre-defined list of words.'''
+	words_to_be_eliminated = ['from', 'subject', 're', 'edu', 'use', 'com', 'https', 'url', 'link', 'abstract', 'author', 'chapter', 'springer', 'title', "the", "of", "and", "in", "to", "a", "is", "for", "from", "with", "that", "by", "are", "on", "was", "as", 
+	"were", "url:", "abstract:", "abstract",  "author:", "title:", "at", "be", "an", "have", "this", "which", "study", "been", "not", "has", "its", "also", "these", "this", "can", "a", 'it', 'their', "e.g.", "those", "had", "but", "while", "will", "when", "only", "author", "title", "there", "our", "did", "as", "if", "they", "such", "than", "no", "-", "could",]
+
 	cleaned_list_of_words_in_abstract = [item for item in list_to_be_cleaned if item not in words_to_be_eliminated]
 
 	list_cleaner_end_status_key = "Cleaned the list of words generated"
